@@ -1,5 +1,5 @@
 import warnings
-from typing import List, Optional, Union
+from typing import List, Optional, Tuple, Union
 
 import gmsh
 
@@ -13,6 +13,7 @@ from .line import Line
 from .plane_surface import PlaneSurface
 from .point import Point
 from .polygon import Polygon
+from .size_field import BoundaryLayer, SetBackgroundMesh
 from .spline import Spline
 from .surface import Surface
 from .surface_loop import SurfaceLoop
@@ -24,8 +25,9 @@ class CommonGeometry:
     and occ.
     """
 
-    def __init__(self, env):
+    def __init__(self, env, init_argv=None):
         self.env = env
+        self.init_argv = init_argv
         self._COMPOUND_ENTITIES = []
         self._RECOMBINE_ENTITIES = []
         self._EMBED_QUEUE = []
@@ -38,7 +40,8 @@ class CommonGeometry:
         self._OUTWARD_NORMALS = []
 
     def __enter__(self):
-        gmsh.initialize()
+
+        gmsh.initialize([] if self.init_argv is None else self.init_argv)
         gmsh.model.add("pygmsh model")
         return self
 
@@ -117,15 +120,17 @@ class CommonGeometry:
 
         self._PHYSICAL_QUEUE.append((entities, label))
 
-    def set_transfinite_curve(self, curve, num_nodes, mesh_type, coeff):
+    def set_transfinite_curve(
+        self, curve, num_nodes: int, mesh_type: str, coeff: float
+    ):
         assert mesh_type in ["Progression", "Bulk"]
         self._TRANSFINITE_CURVE_QUEUE.append((curve._id, num_nodes, mesh_type, coeff))
 
-    def set_transfinite_surface(self, surface, arrangement, corner_pts):
+    def set_transfinite_surface(self, surface, arrangement: str, corner_pts):
         corner_tags = [pt._id for pt in corner_pts]
         self._TRANSFINITE_SURFACE_QUEUE.append((surface._id, arrangement, corner_tags))
 
-    def set_transfinite_volume(self, volume, arrangement, corner_pts):
+    def set_transfinite_volume(self, volume, corner_pts):
         corner_tags = [pt._id for pt in corner_pts]
         self._TRANSFINITE_VOLUME_QUEUE.append((volume._id, corner_tags))
 
@@ -137,7 +142,7 @@ class CommonGeometry:
     def extrude(
         self,
         input_entity,
-        translation_axis,
+        translation_axis: Tuple[float, float, float],
         num_layers: Optional[Union[int, List[int]]] = None,
         heights: Optional[List[float]] = None,
         recombine: bool = False,
@@ -174,8 +179,8 @@ class CommonGeometry:
     def _revolve(
         self,
         input_entity,
-        rotation_axis: List[float],
-        point_on_axis: List[float],
+        rotation_axis: Tuple[float, float, float],
+        point_on_axis: Tuple[float, float, float],
         angle: float,
         num_layers: Optional[Union[int, List[int]]] = None,
         heights: Optional[List[float]] = None,
@@ -210,15 +215,21 @@ class CommonGeometry:
         lateral = [Dummy(*e) for e in out_dim_tags[2:]]
         return top, extruded, lateral
 
-    def translate(self, obj, vector):
+    def translate(self, obj, vector: Tuple[float, float, float]):
         """Translates input_entity itself by vector.
 
         Changes the input object.
         """
         self.env.translate(obj.dim_tags, *vector)
 
-    def rotate(self, obj, point, angle, axis):
-        """Rotate input_entity around a given point with a give angle.
+    def rotate(
+        self,
+        obj,
+        point: Tuple[float, float, float],
+        angle: float,
+        axis: Tuple[float, float, float],
+    ):
+        """Rotate input_entity around a given point with a given angle.
            Rotation axis has to be specified.
 
         Changes the input object.
@@ -230,19 +241,21 @@ class CommonGeometry:
         assert len(dim_tag) == 1
         return Dummy(*dim_tag[0])
 
-    def symmetrize(self, obj, coefficients):
+    def symmetrize(self, obj, coefficients: Tuple[float, float, float, float]):
         """Transforms all elementary entities symmetrically to a plane. The vector
         should contain four expressions giving the coefficients of the plane's equation.
         """
         self.env.symmetrize(obj.dim_tags, *coefficients)
 
-    def dilate(self, obj, x0, abc):
+    def dilate(
+        self, obj, x0: Tuple[float, float, float], abc: Tuple[float, float, float]
+    ):
         self.env.dilate(obj.dim_tags, *x0, *abc)
 
-    def mirror(self, obj, abcd):
+    def mirror(self, obj, abcd: Tuple[float, float, float, float]):
         self.env.mirror(obj.dim_tags, *abcd)
 
-    def remove(self, obj, recursive=False):
+    def remove(self, obj, recursive: bool = False):
         self.env.remove(obj.dim_tags, recursive=recursive)
 
     def in_surface(self, input_entity, surface):
@@ -288,6 +301,15 @@ class CommonGeometry:
             gmsh.option.setNumber("Mesh.CharacteristicLengthFromPoints", 0)
             gmsh.option.setNumber("Mesh.CharacteristicLengthFromCurvature", 0)
 
+    def add_boundary_layer(self, *args, **kwargs):
+        layer = BoundaryLayer(*args, **kwargs)
+        self._AFTER_SYNC_QUEUE.append(layer)
+        return layer
+
+    def set_background_mesh(self, *args, **kwargs):
+        setter = SetBackgroundMesh(*args, **kwargs)
+        self._AFTER_SYNC_QUEUE.append(setter)
+
     def generate_mesh(  # noqa: C901
         self,
         dim: int = 3,
